==> vtk6-6.3.0-2-aarch64.pkg.tar.xz: vtk/vtkSQLDatabaseTableSource.java <==
// java wrapper for vtkSQLDatabaseTableSource object
//

package vtk;
import vtk.*;

public class vtkSQLDatabaseTableSource extends vtkTableAlgorithm
{

  private native String GetClassName_0();
  public String GetClassName()
    { return GetClassName_0(); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetURL_2();
  public String GetURL()
    { return GetURL_2(); }

  private native void SetURL_3(String id0);
  public void SetURL(String id0)
    { SetURL_3(id0); }

  private native void SetPassword_4(String id0);
  public void SetPassword(String id0)
    { SetPassword_4(id0); }

  private native String GetQuery_5();
  public String GetQuery()
    { return GetQuery_5(); }

  private native void SetQuery_6(String id0);
  public void SetQuery(String id0)
    { SetQuery_6(id0); }

  private native void SetPedigreeIdArrayName_7(String id0);
  public void SetPedigreeIdArrayName(String id0)
    { SetPedigreeIdArrayName_7(id0); }

  private native String GetPedigreeIdArrayName_8();
  public String GetPedigreeIdArrayName()
    { return GetPedigreeIdArrayName_8(); }

  private native void SetGeneratePedigreeIds_9(boolean id0);
  public void SetGeneratePedigreeIds(boolean id0)
    { SetGeneratePedigreeIds_9(id0); }

  private native boolean GetGeneratePedigreeIds_10();
  public boolean GetGeneratePedigreeIds()
    { return GetGeneratePedigreeIds_10(); }

  private native void GeneratePedigreeIdsOn_11();
  public void GeneratePedigreeIdsOn()
    { GeneratePedigreeIdsOn_11(); }

  private native void GeneratePedigreeIdsOff_12();
  public void GeneratePedigreeIdsOff()
    { GeneratePedigreeIdsOff_12(); }

  public vtkSQLDatabaseTableSource() { super(); }

  public vtkSQLDatabaseTableSource(long id) { super(id); }
  public native long   VTKInit();

}

==> vtk-8.2.0-3-aarch64.pkg.tar.xz: vtk/vtkSQLDatabaseTableSource.java <==
// java wrapper for vtkSQLDatabaseTableSource object
//

package vtk;
import vtk.*;

public class vtkSQLDatabaseTableSource extends vtkTableAlgorithm
{

  private native int IsTypeOf_0(String id0);
  public int IsTypeOf(String id0)
    { return IsTypeOf_0(id0); }

  private native int IsA_1(String id0);
  public int IsA(String id0)
    { return IsA_1(id0); }

  private native String GetURL_2();
  public String GetURL()
    { return GetURL_2(); }

  private native void SetURL_3(String id0);
  public void SetURL(String id0)
    { SetURL_3(id0); }

  private native void SetPassword_4(String id0);
  public void SetPassword(String id0)
    { SetPassword_4(id0); }

  private native String GetQuery_5();
  public String GetQuery()
    { return GetQuery_5(); }

  private native void SetQuery_6(String id0);
  public void SetQuery(String id0)
    { SetQuery_6(id0); }

  private native void SetPedigreeIdArrayName_7(String id0);
  public void SetPedigreeIdArrayName(String id0)
    { SetPedigreeIdArrayName_7(id0); }

  private native String GetPedigreeIdArrayName_8();
  public String GetPedigreeIdArrayName()
    { return GetPedigreeIdArrayName_8(); }

  private native void SetGeneratePedigreeIds_9(boolean id0);
  public void SetGeneratePedigreeIds(boolean id0)
    { SetGeneratePedigreeIds_9(id0); }

  private native boolean GetGeneratePedigreeIds_10();
  public boolean GetGeneratePedigreeIds()
    { return GetGeneratePedigreeIds_10(); }

  private native void GeneratePedigreeIdsOn_11();
  public void GeneratePedigreeIdsOn()
    { GeneratePedigreeIdsOn_11(); }

  private native void GeneratePedigreeIdsOff_12();
  public void GeneratePedigreeIdsOff()
    { GeneratePedigreeIdsOff_12(); }

  public vtkSQLDatabaseTableSource() { super(); }

  public vtkSQLDatabaseTableSource(long id) { super(id); }
  public native long   VTKInit();

}
